/* Copyright (c) 1990 by Carrick Sean Casey. */
/* For copying and distribution information, see the file COPYING. */

/* parse a line from the user */

#include "fn.h"
#include "externs.h"

extern Tcl_Interp *interp;
char *nextword();

char *argv[10];

parse(s)
char *s;
{
	char cmdbuf[1024], *p;
	int result;
	char *line = s;

	/* see if it's just text meant for the group */
	if (*s != gv.cmdchar || *s == PERMCMDCHAR) {
		putl(s, PL_LOG | PL_BUF);
		csendopen(s);
		return;
	}

	/* first char must have been the command char, skip over it */
	s++;

	/* check to see if it's a personal */
	if (wordcmp(s, "m") == 0) {
		putl(line, PL_LOG | PL_BUF); /* already written to screen */
		sendpersonal(nextword(s));
		return;
	}

	/* check to see if it's a shell command */
	/* what a mess, but it works */
	if (*s == '!') {
		char *w;
		s++;

		if (gv.restricted) {
		   putl("[Error] c_shell: no shell commands in restricted mode",
		    PL_SCR);
		 return;
		}

		if ((*s == ' ' || *s == '\t') && ((w = nextword(s)) != NULL)) {
			argv[0] = "c_shell"; argv[1] = w; argv[2] = NULL;
			c_shell(NULL, interp, 2, argv);
		} else if (*s != '\0') {
			argv[0] = "c_shell"; argv[1] = s; argv[2] = NULL;
			c_shell(NULL, interp, 2, argv);
		} else {
			argv[0] = "c_shell"; argv[1] = NULL;
			c_shell(NULL, interp, 1, argv);
		}
		return;
	}

	/* a doubled command char means use it literally */
	if (*s == gv.cmdchar) {
		putl(s, PL_LOG | PL_BUF);
		csendopen(s);
		return;
	}

	/* check to see if it's a tcl special */
	if (wordcmp(s, "tcl") == 0) {
		s += 3;
	} else {
		/* if not, quote the text */
		quoteify(s, cmdbuf);
		s = cmdbuf;
	}

	putl(line, PL_LOG);

	/* call TCL to evaluate the string */
	result = Tcl_Eval(interp, s, 0, &p);

	/* print the results */
	if (result == TCL_OK) {
		if (*interp->result != 0)
			putl(interp->result, PL_SCR | PL_LOG);
	} else {
		if (interp->result) {
			sprintf(mbuf, "[Error] %s", interp->result);
			putl(mbuf, PL_SCR | PL_LOG);
		} else
			putl("[Error] Unknown Tcl error", PL_SCR | PL_LOG);
	}
}

#ifdef NEVER
/* compare the first word in s1 with s2 */
wordcmp(s1, s2)
char *s1;
char *s2;
{
	char *p = s1;
	int count = 0;
	while (*p != ' ' && *p != '\t' && *p != '\0') {
		count++;
		p++;
	}
	if (count)
		return(strncmp(s1, s2, count));
	else
		return(1);
}
#endif NEVER

/* starting at a word, find the start of the next one */
char *nextword(s)
char *s;
{
	while (*s != ' ' && *s != '\t' && *s != '\0') s++;
	while ((*s == ' ' || *s == '\t') && *s != '\0') s++;
	if (*s == '\0')
		return(0);
	else
		return(s);
}
